# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.4.4] - 2025-12-11

### Added
- **skills**: update skill implementations (06ad51c)

## [1.4.3] - 2025-12-11

### Added
- **skills**: add SKILL.md skill (3ea7076)

## [1.4.2] - 2025-12-10

## [1.4.1] - 2025-12-08

### Added
- **commands**: update slash commands (66f839a)

## [1.4.0] - 2025-12-08

### Added
- **commands**: add speckit.taskstoissues command (d3e994b)

## [1.3.1] - 2025-12-03

## [1.3.0] - 2025-11-28

### Added
- **commands**: update slash commands (7ca6888)

## [1.2.5] - 2025-11-27

### Added
- add Serena MCP and DeksdenFlow integration (8bb40b2)
- **rules**: add LIBRARY-FIRST approach to orchestration rules (cbafa9a)
- **agents**: add reuse-hunting workflow agents (92e8a7a)

## [1.2.4] - 2025-11-22

## [1.2.3] - 2025-11-21

## [1.2.2] - 2025-11-21

## [1.2.1] - 2025-11-21

## [1.2.0] - 2025-11-21

### Added
- **ci**: add automatic npm publish on tag push (94cfc33)

## [1.1.11] - 2025-11-21

## [1.1.10] - 2025-11-19

### Added
- **release**: enhanced auto-commit type detection with priorities (222af75)

## [1.1.9] - 2025-11-19

### Added
- **release**: smart auto-commit type detection (49af988)

## [1.1.8] - 2025-11-19

### Fixed
- **release**: clean up backup files before git add (af19d7e)

## [1.1.7] - 2025-11-19

## [1.1.6] - 2025-11-19

## [1.1.5] - 2025-11-17

## [1.1.4] - 2025-11-17

## [1.1.3] - 2025-11-17

### Fixed
- **speckit**: correct Phase 0 format and execution order (a7025f7)

## [1.1.2] - 2025-11-14

## [1.1.1] - 2025-11-11
